package com.ruoyi.web.controller.post;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.post.domain.PostNews;
import com.ruoyi.post.service.IPostNewsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 通知消息管理; InnoDB free: 8192 kBController
 *
 * @author ruoyi
 * @date 2023-01-17
 */
@RestController
@RequestMapping("/post/news")
public class PostNewsController extends BaseController
{
    @Autowired
    private IPostNewsService postNewsService;

    /**
     * 查询通知消息管理;
     */
    @PreAuthorize("@ss.hasPermi('system:news:list')")
    @GetMapping("/list")
    public TableDataInfo list(PostNews postNews)
    {
        startPage();
        List<PostNews> list = postNewsService.selectPostNewsList(postNews);
        return getDataTable(list);
    }

    /**
     * 导出通知消息管理;
     */
    @PreAuthorize("@ss.hasPermi('system:news:export')")
    @Log(title = "通知消息管理; InnoDB free: 8192 kB", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PostNews postNews)
    {
        List<PostNews> list = postNewsService.selectPostNewsList(postNews);
        ExcelUtil<PostNews> util = new ExcelUtil<PostNews>(PostNews.class);
        util.exportExcel(response, list, "通知消息管理; InnoDB free: 8192 kB数据");
    }

    /**
     * 获取通知消息管理;
     */
    @PreAuthorize("@ss.hasPermi('system:news:query')")
    @GetMapping(value = "/{newsId}")
    public AjaxResult getInfo(@PathVariable("newsId") Integer newsId)
    {
        return success(postNewsService.selectPostNewsByNewsId(newsId));
    }

    /**
     * 新增通知消息管理;
     */
    @PreAuthorize("@ss.hasPermi('system:news:add')")
    @Log(title = "通知消息管理; InnoDB free: 8192 kB", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PostNews postNews)
    {
        return toAjax(postNewsService.insertPostNews(postNews));
    }

    /**
     * 修改通知消息管理;
     */
    @PreAuthorize("@ss.hasPermi('system:news:edit')")
    @Log(title = "通知消息管理; InnoDB free: 8192 kB", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PostNews postNews)
    {
        return toAjax(postNewsService.updatePostNews(postNews));
    }

    /**
     * 删除通知消息管理;
     */
    @PreAuthorize("@ss.hasPermi('system:news:remove')")
    @Log(title = "通知消息管理; InnoDB free: 8192 kB", businessType = BusinessType.DELETE)
    @DeleteMapping("/{newsIds}")
    public AjaxResult remove(@PathVariable Integer[] newsIds)
    {
        return toAjax(postNewsService.deletePostNewsByNewsIds(newsIds));
    }

}